Class: Semverve::Finding
- Inherits:
-
Object
- Object
- Semverve::Finding
- Defined in:
- lib/semverve/finding.rb
Overview
A version mismatch found by a Semverve check.
Instance Attribute Summary collapse
-
#column ⇒ Integer
readonly
One-based column number.
-
#label ⇒ String?
readonly
Optional output label for findings that carry their own label.
-
#line ⇒ Integer
readonly
One-based line number.
-
#path ⇒ String
readonly
Path relative to the configured project root.
-
#version ⇒ Semverve::SemanticVersion
readonly
Referenced semantic version.
Instance Method Summary collapse
-
#initialize(path:, line:, column:, version:, label: nil) ⇒ Semverve::Finding
constructor
Initializes a finding.
Constructor Details
#initialize(path:, line:, column:, version:, label: nil) ⇒ Semverve::Finding
Initializes a finding.
47 48 49 50 51 52 53 |
# File 'lib/semverve/finding.rb', line 47 def initialize(path:, line:, column:, version:, label: nil) @path = path @line = line @column = column @version = version @label = label end |
Instance Attribute Details
#column ⇒ Integer (readonly)
One-based column number.
23 24 25 |
# File 'lib/semverve/finding.rb', line 23 def column @column end |
#label ⇒ String? (readonly)
Optional output label for findings that carry their own label.
35 36 37 |
# File 'lib/semverve/finding.rb', line 35 def label @label end |
#line ⇒ Integer (readonly)
One-based line number.
17 18 19 |
# File 'lib/semverve/finding.rb', line 17 def line @line end |
#path ⇒ String (readonly)
Path relative to the configured project root.
11 12 13 |
# File 'lib/semverve/finding.rb', line 11 def path @path end |
#version ⇒ Semverve::SemanticVersion (readonly)
Referenced semantic version.
29 30 31 |
# File 'lib/semverve/finding.rb', line 29 def version @version end |